@@ -13,7 +13,7 @@
 #ifndef EPT_PACKGEDETAILS_H
 #define EPT_PACKGEDETAILS_H
 
-class KToolBarButton;
+class TDEToolBarButton;
 class TQThread;
 
 namespace adept {
@@ -24,7 +24,7 @@ class PackageDetails : public PackageDetailsUi, public Lister::RangeProvider,
                        public cache::Observer
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     enum ButtonID { BForward, BBack, BShow };
     PackageDetails( TQWidget *p = 0, const char *n = 0 );
